@@ -1,18 +1,3 @@
-#' Example datasets used in the vignette
-#' @description Recreated after the example data from corresponding Stata
-#'   function.
-#' @name sdc_DT
-#' @docType data
-#' @usage data("sdc_DT")
-#' @format A data.table with 100 rows and 8 columns.
-#' @details The data.table contains the following columns:
-#' - id [integer] random identifier
-#' - time [integer] random time variable
-#' - V1 - V3 [numeric] random variables
-#' - D1 - D3 [logical] non-random dummy variables
-#' @keywords datasets
-"sdc_DT"
-
 #' Example data for `sdc_descriptives()`
 #' @description Utilized in the vignette.
 #' @name sdc_descriptives_DT
@@ -40,11 +25,11 @@
 #' @keywords datasets
 "sdc_model_DT"
 
-#' Example data for `sdc_extreme()`
+#' Example data for `sdc_min_max()`
 #' @description Utilized in the vignette
-#' @name sdc_extreme_DT
+#' @name sdc_min_max_DT
 #' @docType data
-#' @usage data("sdc_extreme_DT")
+#' @usage data("sdc_min_max_DT")
 #' @format A data.table with 20 rows and 6 columns.
 #' @details The data.table contains the following columns:
 #' - id [factor] random identifier
@@ -52,4 +37,4 @@
 #' - year [integer] time variable
 #' - val_1 - val_3 [numeric] value variables
 #' @keywords datasets
-"sdc_extreme_DT"
+"sdc_min_max_DT"
