@@ -2,6 +2,8 @@
 #' @description Checks if any check on distinct ID's was problematic and throws
 #'   a single warning.
 #' @param list [list] of elements of class `sdc_distinct_ids`.
+#' @importFrom data.table between
+#' @importFrom crayon bold
 #' @return NULL
 #' @noRd
 warn_distinct_ids <- function(list) {
@@ -9,7 +11,16 @@ warn_distinct_ids <- function(list) {
 
     problems <- vapply(
         list,
-        function(x) nrow(x[distinct_ids < getOption("sdc.n_ids", 5L)]) > 0L,
+        function(x) {
+            var_names <- setdiff(names(x), "distinct_ids")
+            x_non_zero <- subset_zero(x, var_names)
+            nrow(x_non_zero[data.table::between(
+                distinct_ids,
+                lower = 0L,
+                upper = getOption("sdc.n_ids", 5L),
+                incbounds = FALSE)]
+            ) > 0L
+        },
         FUN.VALUE = logical(1L)
     )
 
